API Reference
=============

.. automodule:: scitex_ui
   :members:
   :undoc-members:
   :show-inheritance:

Registry
--------

.. automodule:: scitex_ui._registry
   :members:
   :undoc-members:

Components
----------

.. automodule:: scitex_ui._components._theme_provider
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: scitex_ui._components._app_shell
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: scitex_ui._components._status_bar
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: scitex_ui._components._file_browser
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: scitex_ui._components._package_docs_sidebar
   :members:
   :undoc-members:
   :show-inheritance:
